# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/context_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.context import types_pb2 as t2iapi_dot_context_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%t2iapi/context/context_requests.proto\x12\x0et2iapi.context\x1a\x1at2iapi/context/types.proto\"9\n\x19\x43ontextStateHandleRequest\x12\x1c\n\x14\x63ontext_state_handle\x18\x01 \x01(\t\"L\n\x18SetLocationDetailRequest\x12\x30\n\x08location\x18\x01 \x01(\x0b\x32\x1e.t2iapi.context.LocationDetail\"\x9d\x01\n!SetContextStateAssociationRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12\x1c\n\x14\x63ontext_state_handle\x18\x02 \x01(\t\x12?\n\x13\x63ontext_association\x18\x03 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\"\x86\x01\n(CreateContextStateWithAssociationRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\"\xab\x01\n5CreateContextStateWithAssociationAndValidatorsRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\x12\x16\n\x0enum_validators\x18\x03 \x01(\t\"\xcb\x01\n6CreateContextStateWithAssocAndSpecificValidatorRequest\x12\x19\n\x11\x64\x65scriptor_handle\x18\x01 \x01(\t\x12?\n\x13\x63ontext_association\x18\x02 \x01(\x0e\x32\".t2iapi.context.ContextAssociation\x12\x35\n\x0evalidator_type\x18\x03 \x01(\x0e\x32\x1d.t2iapi.context.ValidatorType\"L\n\x17\x41ssociatePatientRequest\x12\x31\n\x0cpatient_type\x18\x01 \x01(\x0e\x32\x1b.t2iapi.context.PatientTypeB5\n\"com.draeger.medical.t2iapi.contextB\x0f\x43ontextRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.context_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\017ContextRequests'
  _CONTEXTSTATEHANDLEREQUEST._serialized_start=85
  _CONTEXTSTATEHANDLEREQUEST._serialized_end=142
  _SETLOCATIONDETAILREQUEST._serialized_start=144
  _SETLOCATIONDETAILREQUEST._serialized_end=220
  _SETCONTEXTSTATEASSOCIATIONREQUEST._serialized_start=223
  _SETCONTEXTSTATEASSOCIATIONREQUEST._serialized_end=380
  _CREATECONTEXTSTATEWITHASSOCIATIONREQUEST._serialized_start=383
  _CREATECONTEXTSTATEWITHASSOCIATIONREQUEST._serialized_end=517
  _CREATECONTEXTSTATEWITHASSOCIATIONANDVALIDATORSREQUEST._serialized_start=520
  _CREATECONTEXTSTATEWITHASSOCIATIONANDVALIDATORSREQUEST._serialized_end=691
  _CREATECONTEXTSTATEWITHASSOCANDSPECIFICVALIDATORREQUEST._serialized_start=694
  _CREATECONTEXTSTATEWITHASSOCANDSPECIFICVALIDATORREQUEST._serialized_end=897
  _ASSOCIATEPATIENTREQUEST._serialized_start=899
  _ASSOCIATEPATIENTREQUEST._serialized_end=975
# @@protoc_insertion_point(module_scope)
