# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/activation_state/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/activation_state/types.proto\x12\x17t2iapi.activation_state*\xdb\x01\n\x13\x43omponentActivation\x12\x1b\n\x17\x43OMPONENT_ACTIVATION_ON\x10\x00\x12\"\n\x1e\x43OMPONENT_ACTIVATION_NOT_READY\x10\x01\x12 \n\x1c\x43OMPONENT_ACTIVATION_STANDBY\x10\x02\x12\x1c\n\x18\x43OMPONENT_ACTIVATION_OFF\x10\x03\x12!\n\x1d\x43OMPONENT_ACTIVATION_SHUTDOWN\x10\x04\x12 \n\x1c\x43OMPONENT_ACTIVATION_FAILURE\x10\x05*^\n\x0f\x41lertActivation\x12\x17\n\x13\x41LERT_ACTIVATION_ON\x10\x00\x12\x18\n\x14\x41LERT_ACTIVATION_OFF\x10\x01\x12\x18\n\x14\x41LERT_ACTIVATION_PSD\x10\x02*\xaa\x01\n\x18\x41lertSignalManifestation\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_AUD\x10\x00\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_VIS\x10\x01\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_TAN\x10\x02\x12\"\n\x1e\x41LERT_SIGNAL_MANIFESTATION_OTH\x10\x03\x42\x43\n+com.draeger.medical.t2iapi.activation_stateB\x14\x41\x63tivationStateTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.activation_state.types_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.draeger.medical.t2iapi.activation_stateB\024ActivationStateTypes'
  _COMPONENTACTIVATION._serialized_start=65
  _COMPONENTACTIVATION._serialized_end=284
  _ALERTACTIVATION._serialized_start=286
  _ALERTACTIVATION._serialized_end=380
  _ALERTSIGNALMANIFESTATION._serialized_start=383
  _ALERTSIGNALMANIFESTATION._serialized_end=553
# @@protoc_insertion_point(module_scope)
