# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.metric import metric_requests_pb2 as t2iapi_dot_metric_dot_metric__requests__pb2
from t2iapi.metric import metric_responses_pb2 as t2iapi_dot_metric_dot_metric__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/metric/service.proto\x12\rt2iapi.metric\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a#t2iapi/metric/metric_requests.proto\x1a$t2iapi/metric/metric_responses.proto2\xbb\x07\n\rMetricService\x12\x61\n\x18SetMetricQualityValidity\x12..t2iapi.metric.SetMetricQualityValidityRequest\x1a\x15.t2iapi.BasicResponse\x12?\n\nSetNoValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x83\x01\n)SetActivationStateAndUserConfirmableValue\x12?.t2iapi.metric.SetActivationStateAndUserConfirmableValueRequest\x1a\x15.t2iapi.BasicResponse\x12\x44\n\x0fSetInvalidValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12U\n\x0f\x43\x61librateMetric\x12\x1a.t2iapi.BasicHandleRequest\x1a&.t2iapi.metric.CalibrateMetricResponse\x12m\n\x1eSetMetricValuesWithQualityMode\x12\x34.t2iapi.metric.SetMetricValuesWithQualityModeRequest\x1a\x15.t2iapi.BasicResponse\x12]\n\x16SetMetricValuesInRange\x12,.t2iapi.metric.SetMetricValuesInRangeRequest\x1a\x15.t2iapi.BasicResponse\x12\x63\n\x19\x43hangeOperationModeStatus\x12/.t2iapi.metric.ChangeOperationModeStatusRequest\x1a\x15.t2iapi.BasicResponse\x12O\n\x0fSetMetricStatus\x12%.t2iapi.metric.SetMetricStatusRequest\x1a\x15.t2iapi.BasicResponse\x12_\n\x14IsComputerControlled\x12\x1a.t2iapi.BasicHandleRequest\x1a+.t2iapi.metric.IsComputerControlledResponseB5\n!com.draeger.medical.t2iapi.metricB\x10MetricApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\020MetricApiService'
  _METRICSERVICE._serialized_start=181
  _METRICSERVICE._serialized_end=1136
# @@protoc_insertion_point(module_scope)
