# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/context/service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi.context import context_requests_pb2 as t2iapi_dot_context_dot_context__requests__pb2
from t2iapi.context import context_responses_pb2 as t2iapi_dot_context_dot_context__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ct2iapi/context/service.proto\x12\x0et2iapi.context\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1bt2iapi/basic_requests.proto\x1a\x1ct2iapi/basic_responses.proto\x1a%t2iapi/context/context_requests.proto\x1a&t2iapi/context/context_responses.proto2\xc8\x10\n\x0e\x43ontextService\x12T\n\x11SetLocationDetail\x12(.t2iapi.context.SetLocationDetailRequest\x1a\x15.t2iapi.BasicResponse\x12\x63\n\x1fRemoveAllContextStateValidators\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\x1aSetContextStateAssociation\x12\x31.t2iapi.context.SetContextStateAssociationRequest\x1a\x15.t2iapi.BasicResponse\x12\x98\x01\n!CreateContextStateWithAssociation\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xb2\x01\n.CreateContextStateWithAssociationAndValidators\x12\x45.t2iapi.context.CreateContextStateWithAssociationAndValidatorsRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xc6\x01\n8CreateContextStateWithAssociationAndUniqueIdentification\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1aP.t2iapi.context.CreateContextStateWithAssociationAndUniqueIdentificationResponse\x12\x88\x01\n5CreateContextStateWithAssocIdentificationAndValidator\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\"RemoveIdentificationOfContextState\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x66\n\"ChangeIdentificationOfContextState\x12).t2iapi.context.ContextStateHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\xb4\x01\n/CreateContextStateWithAssocAndSpecificValidator\x12\x46.t2iapi.context.CreateContextStateWithAssocAndSpecificValidatorRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12\xb3\x01\n<CreateNeonatalPatientWithAssociationAndMothersIdentification\x12\x38.t2iapi.context.CreateContextStateWithAssociationRequest\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponse\x12R\n\x10\x41ssociatePatient\x12\'.t2iapi.context.AssociatePatientRequest\x1a\x15.t2iapi.BasicResponse\x12V\n!EnsembleContextIndicateMembership\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x9e\x01\n3EnsembleContextIndicateMembershipWithIdentification\x12\x1a.t2iapi.BasicHandleRequest\x1aK.t2iapi.context.EnsembleContextIndicateMembershipWithIdentificationResponse\x12\x64\n\x18GetSupportedContextTypes\x12\x16.google.protobuf.Empty\x1a\x30.t2iapi.context.GetSupportedContextTypesResponse\x12\x7f\n*AssociatePatientWithAutoGeneratedPatientId\x12\x16.google.protobuf.Empty\x1a\x39.t2iapi.context.CreateContextStateWithAssociationResponseB7\n\"com.draeger.medical.t2iapi.contextB\x11\x43ontextApiServiceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.context.service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.draeger.medical.t2iapi.contextB\021ContextApiService'
  _CONTEXTSERVICE._serialized_start=216
  _CONTEXTSERVICE._serialized_end=2336
# @@protoc_insertion_point(module_scope)
