# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.device import types_pb2 as t2iapi_dot_device_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/device/device_requests.proto\x12\rt2iapi.device\x1a\x19t2iapi/device/types.proto\"A\n\x14TriggerReportRequest\x12)\n\x06report\x18\x01 \x01(\x0e\x32\x19.t2iapi.device.ReportType\"N\n\x1dSetDeviceOperatingModeRequest\x12-\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.t2iapi.device.MdsOperatingMode\"&\n\x12SetLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"7\n\x1b\x43hangeMdibSequenceIdRequest\x12\x18\n\x10\x64\x65scriptive_name\x18\x01 \x01(\t\"a\n%GetRemovableDescriptorsOfClassRequest\x12\x38\n\x10\x64\x65scriptor_class\x18\x01 \x01(\x0e\x32\x1e.t2iapi.device.DescriptorClassB3\n!com.draeger.medical.t2iapi.deviceB\x0e\x44\x65viceRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.device.device_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\016DeviceRequests'
  _TRIGGERREPORTREQUEST._serialized_start=81
  _TRIGGERREPORTREQUEST._serialized_end=146
  _SETDEVICEOPERATINGMODEREQUEST._serialized_start=148
  _SETDEVICEOPERATINGMODEREQUEST._serialized_end=226
  _SETLANGUAGEREQUEST._serialized_start=228
  _SETLANGUAGEREQUEST._serialized_end=266
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_start=268
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_end=323
  _GETREMOVABLEDESCRIPTORSOFCLASSREQUEST._serialized_start=325
  _GETREMOVABLEDESCRIPTORSOFCLASSREQUEST._serialized_end=422
# @@protoc_insertion_point(module_scope)
