# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_requests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.activation_state import types_pb2 as t2iapi_dot_activation__state_dot_types__pb2
from t2iapi.metric import types_pb2 as t2iapi_dot_metric_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/metric/metric_requests.proto\x12\rt2iapi.metric\x1a#t2iapi/activation_state/types.proto\x1a\x19t2iapi/metric/types.proto\"g\n\x1fSetMetricQualityValidityRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x34\n\x08validity\x18\x02 \x01(\x0e\x32\".t2iapi.metric.MeasurementValidity\"d\n%SetMetricValuesWithQualityModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x04mode\x18\x02 \x01(\x0e\x32\x1d.t2iapi.metric.GenerationMode\"M\n\x1dSetMetricValuesInRangeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\r\n\x05lower\x18\x02 \x01(\t\x12\r\n\x05upper\x18\x03 \x01(\t\"u\n ChangeOperationModeStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x41\n\x15operation_mode_status\x18\x02 \x01(\x0e\x32\".t2iapi.metric.OperationModeStatus\"U\n\x16SetMetricStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.t2iapi.metric.MetricStatus\"\x84\x01\n0SetActivationStateAndUserConfirmableValueRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12@\n\nactivation\x18\x02 \x01(\x0e\x32,.t2iapi.activation_state.ComponentActivationB3\n!com.draeger.medical.t2iapi.metricB\x0eMetricRequestsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 't2iapi.metric.metric_requests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\016MetricRequests'
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_start=118
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_end=221
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_start=223
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_end=323
  _SETMETRICVALUESINRANGEREQUEST._serialized_start=325
  _SETMETRICVALUESINRANGEREQUEST._serialized_end=402
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_start=404
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_end=521
  _SETMETRICSTATUSREQUEST._serialized_start=523
  _SETMETRICSTATUSREQUEST._serialized_end=608
  _SETACTIVATIONSTATEANDUSERCONFIRMABLEVALUEREQUEST._serialized_start=611
  _SETACTIVATIONSTATEANDUSERCONFIRMABLEVALUEREQUEST._serialized_end=743
# @@protoc_insertion_point(module_scope)
